truncated property
bool
get
truncated
Returns true if generation was truncated by the maxTokens limit.
Implementation
bool get truncated => finishReason == 'length';
Returns true if generation was truncated by the maxTokens limit.
bool get truncated => finishReason == 'length';