GgufModelConfig class
Configuration for loading a pre-quantised GGUF model.
Constructors
Properties
- approxMemory → String
-
Approximate memory footprint, e.g.
"~941 MB (GGUF Q4_K_M)".final - displayName → String
-
Human-friendly display name, e.g.
"Qwen 2.5 1.5B".final -
files
→ List<
String> -
GGUF filename(s) within the repository.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- modelId → String
-
HuggingFace repository ID, e.g.
"bartowski/Qwen2.5-1.5B-Instruct-GGUF".final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokModelId → String?
-
Optional explicit tokenizer model ID (required on Android).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override